@@ -26,7 +26,7 @@ class Env:
 
 _env_map = {
     APIEnv.local: Env(
-        api_url='localhost:8000',
+        api_url='http://localhost:8000',
         chunk_url_template=Template('http://localhost:8081/storage/v1/b/cdn.dev.vankrupt.io/o/$mod_id/$hash'),
         modprocessing_url='http://localhost:9000/uploaded',
         upload_bucket_name='upload.dev.vankrupt.io',
